pub struct PendingSessionInference { /* private fields */ }Expand description
An owned provider operation that can wait without borrowing a Session.
Implementations
Sourceimpl PendingSessionInference
impl PendingSessionInference
Sourcepub async fn wait(self) -> SessionInferenceWake
pub async fn wait(self) -> SessionInferenceWake
Waits for one provider start, stream, or native response operation.